require "atende_simples_api/version"
require "faraday"

module AtendeSimplesAPI
  module V1
    class Client
      DEFAULT_API_URI = 'https://app.atendesimples.com/api/'.freeze

      attr_accessor :token, :api_uri

      def initialize
        @api_uri ||= DEFAULT_API_URI

        yield self
      end
    end

    class Dialer
      class << self
        def dial(client, dial_data)
          new(client, dial_data).dial
        end
      end

      def initialize(client, dial_data)
        @client, @dial_data = client, dial_data
      end

      def dial
        connection.post('dialers', { dialer: @dial_data })
      end

      private

      def connection
        Faraday.new(url: @client.api_uri, ssl: { verify: true }) do |conn|
          conn.use Faraday::Response::RaiseError
          conn.headers['Authorization'] = "Token token=#{@client.token}"
          conn.request :multipart
          conn.request :url_encoded
          conn.adapter :net_http
        end
      end
    end
  end
end
